@@ -8,11 +8,11 @@ test_that("Non-Cellmapping Objects", {
   feat.object = createFeatureObject(X = X, y = rowSums(X^2))
 
   # (2) compute all non-cellmapping and non-expensive features
-  features = calculateFeatures(feat.object,
-    control = list(allow_cellmapping = FALSE, allow_costs = FALSE))
+  expect_warning((features = calculateFeatures(feat.object,
+    control = list(allow_cellmapping = FALSE, allow_costs = FALSE))))
 
   # test return value types and ranges
-  expect_identical(length(features), 94L)
+  expect_identical(length(features), 93L)
   expect_list(features)
 
   # all objects are either NA, logical or a number
@@ -26,15 +26,14 @@ test_that("Non-Cellmapping Objects", {
   expect_identical(features$basic.blocks_max, 1L)
   expect_identical(features$basic.cells_total, 1L)
   expect_identical(features$basic.cells_filled, 1L)
-  expect_identical(features$basic.allows_cm, FALSE)
-
+  
   # (3) do the same, but blacklist the expensive features
-  features = calculateFeatures(feat.object, control = list(
+  expect_warning((features = calculateFeatures(feat.object, control = list(
     allow_cellmapping = FALSE, allow_costs = TRUE, show_progress = FALSE,
-    blacklist = c("ela_local", "ela_curv", "ela_conv")))
+    blacklist = c("ela_local", "ela_curv", "ela_conv")))))
 
   # test return value types and ranges
-  expect_identical(length(features), 94L)
+  expect_identical(length(features), 93L)
   expect_list(features)
 
   # all objects are either NA, logical or a number
@@ -48,12 +47,8 @@ test_that("Non-Cellmapping Objects", {
   expect_identical(features$basic.blocks_max, 1L)
   expect_identical(features$basic.cells_total, 1L)
   expect_identical(features$basic.cells_filled, 1L)
-  expect_identical(features$basic.allows_cm, FALSE)
-
+  
   # (4) test, whether an incorrect input causes an error:
-  expect_error(calculateFeatures(feat.object))
-  expect_error(calculateFeatures(feat.object, allow_costs = FALSE))
-  expect_error(calculateFeatures(feat.object, allow_cellmapping = FALSE))
   expect_error(calculateFeatures(feat.object, control = list(
     subset = c("test123"), allow_costs = FALSE, allow_cellmapping = FALSE)))
 })
@@ -64,14 +59,14 @@ test_that("Cellmapping Objects", {
   # (1) create a feature object:
   X = t(replicate(n = 2000L, expr = runif(n = 5L, min = -10L, max = 10L)))
   y = rowSums(X^2)
-  feat.object = createFeatureObject(X = X, y = y, blocks = c(4, 3, 4, 3, 5))
+  feat.object = createFeatureObject(X = X, y = y, blocks = c(4, 3, 4, 3, 3))
 
   # (2) compute the non-expensive features
   features = calculateFeatures(feat.object, control = list(allow_costs = FALSE,
-    show_progress = FALSE, cm_angle.show_warnings = FALSE))
+    show_progress = FALSE, cm_angle.show_warnings = FALSE, gcm.approaches = "min"))
 
   # test return value types and ranges
-  expect_identical(length(features), 203L)
+  expect_identical(length(features), 183L)
   expect_list(features)
 
   # all objects are either NA, logical or a number
@@ -85,7 +80,6 @@ test_that("Cellmapping Objects", {
   expect_true(testInteger(features$basic.blocks_max))
   expect_true(testInteger(features$basic.cells_total))
   expect_true(testInteger(features$basic.cells_filled))
-  expect_true(features$basic.allows_cm)
 
   # (3) test, whether an incorrect input causes an error:
   expect_error(calculateFeatures(feat.object,
@@ -101,7 +95,7 @@ test_that("Cellmapping Objects", {
     show_progress = FALSE, cm_angle.show_warnings = FALSE))
   
   # test return value types and ranges
-  expect_identical(length(features), 296L)
+  expect_identical(length(features), 295L)
   expect_true(all(vapply(features, length, integer(1L)) ==  1L))
   expect_list(features)
   
@@ -116,7 +110,6 @@ test_that("Cellmapping Objects", {
   expect_true(testInteger(features$basic.blocks_max))
   expect_true(testInteger(features$basic.cells_total))
   expect_true(testInteger(features$basic.cells_filled))
-  expect_true(features$basic.allows_cm)
 })
 
 test_that("Underlying Functions Available (non-cellmapping)", {
@@ -127,11 +120,11 @@ test_that("Underlying Functions Available (non-cellmapping)", {
   feat.object = createFeatureObject(X = X, fun = function(x) sum(x^2))
 
   # (2) compute all non-cm features:
-  features = calculateFeatures(feat.object,
-    control = list(allow_cellmapping = FALSE, show_progress = FALSE))
+  expect_warning((features = calculateFeatures(feat.object,
+    control = list(allow_cellmapping = FALSE, show_progress = FALSE))))
 
   # test return value types and ranges
-  expect_identical(length(features), 142L)
+  expect_identical(length(features), 141L)
   expect_list(features)
 
   # all objects are either NA, logical or a number
@@ -149,11 +142,8 @@ test_that("Underlying Functions Available (non-cellmapping)", {
   expect_identical(features$basic.blocks_max, 1L)
   expect_identical(features$basic.cells_total, 1L)
   expect_identical(features$basic.cells_filled, 1L)
-  expect_identical(features$basic.allows_cm, FALSE)
 
   # (4) test, whether an incorrect input causes an error:
-  expect_error(calculateFeatures(feat.object))
-  expect_error(calculateFeatures(feat.object, control = list(allow_costs = FALSE)))
   expect_error(calculateFeatures(feat.object, control = list(subset = c("test123"), 
     allow_costs = FALSE, allow_cellmapping = FALSE)))
 })
@@ -167,10 +157,10 @@ test_that("Underlying Functions Available (cellmapping)", {
 
   # (2) compute all non-cm features:
   features = calculateFeatures(feat.object,
-    control = list(show_progress = FALSE))
+    control = list(show_progress = FALSE, gcm.approaches = "mean"))
 
   # test return value types and ranges
-  expect_identical(length(features), 251L)
+  expect_identical(length(features), 231L)
   expect_list(features)
 
   # all objects are either NA, logical or a number
@@ -188,7 +178,6 @@ test_that("Underlying Functions Available (cellmapping)", {
   expect_true(testInteger(features$basic.blocks_max))
   expect_true(testInteger(features$basic.cells_total))
   expect_true(testInteger(features$basic.cells_filled))
-  expect_true(features$basic.allows_cm)
 
   # (4) test, whether an incorrect input causes an error:
   expect_error(calculateFeatures(feat.object, control = list(subset = c("test123"), 
