@@ -32,3 +32,19 @@ test_that("GCM features cannot compute on non-cellmapping object", {
   # execution
   expect_error( calculateFeatureSet(feat.object, "gcm") )
 })
+
+test_that("Show Error", {
+  set.seed(2015*03*26)
+  
+  # (1) create a feature object:
+  X = expand.grid(1:4, 1:3)
+  y = c(1, 1, 3, 2, 1, 1, 4, 2.5, 1.5, 2.5, 3.5, 0)
+  feat.object = createFeatureObject(X = X, y = y, blocks = c(4, 3),
+    lower = c(0.5, 0.5), upper = c(4.5, 3.5))
+  
+  expect_error(calculateFeatureSet(feat.object, "gcm",
+    control = list(allow_cellmapping = FALSE)))
+  feat.object = createFeatureObject(X = X, y = y,
+    lower = c(0.5, 0.5), upper = c(4.5, 3.5))
+  expect_error(calculateFeatureSet(feat.object, "gcm"))
+})
