@@ -46,9 +46,6 @@ test_that("Using X and y", {
 })
 
 test_that("Show Error", {
-  feat.object = createFeatureObject(init = iris[, -5], 
-    objective = "Sepal.Length")
-  expect_error(calculateFeatureSet(feat.object, "limo"))
   feat.object = createFeatureObject(init = iris[, -5], 
     objective = "Sepal.Length", blocks = 3L)
   expect_error(calculateFeatureSet(feat.object, "limo",
